<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Omrežni asistent</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="76"/>
        <source>IP address</source>
        <translation>IP naslov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Hardware detected</source>
        <translation>Strojna oprema je bila najdena</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.ui" line="389"/>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Re-scan</source>
        <translation>Ponovi iskanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Active interface</source>
        <translation>Aktivni vmesnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>WiFi status</source>
        <translation>WiFi status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Odblokira vse programsko ali strojno blokirane naprave</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Unblock WiFi Devices</source>
        <translation>Odblokiraj WiFi naprave</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Linux drivers</source>
        <translation>Linux gonilniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Associated Linux drivers</source>
        <translation>Povezani gonilniki za Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Load Driver</source>
        <translation>Naloži gonilnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Unload Driver</source>
        <translation>Odstrani gonilnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Block Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Windows drivers</source>
        <translation>Windows gonilniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="434"/>
        <source>Available Windows drivers</source>
        <translation>Windows gonilniki, ki so na voljo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Remove Driver</source>
        <translation>Odtrsani gonilnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>Add Driver</source>
        <translation>Dodaj gonilnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>About NDISwrapper</source>
        <translation>O programu NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Install NDISwrapper</source>
        <translation>Namesti NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Pred uporabo Windows gonilnikov je najprej potrebno namestiti NDISwrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="559"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Odstrani NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Net diagnostics</source>
        <translation>Diagnostika omrežja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <location filename="../mainwindow.ui" line="726"/>
        <source>Target URL:</source>
        <translation>Ciljni URL:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="619"/>
        <source>Packets</source>
        <translation>Paketi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <location filename="../mainwindow.ui" line="781"/>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="678"/>
        <location filename="../mainwindow.ui" line="798"/>
        <source>Clear</source>
        <translation>Počisti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <location filename="../mainwindow.ui" line="812"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Hops</source>
        <translation>Skoki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="891"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="959"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="966"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>IP address from router:</source>
        <translation>IP naslov usmerjevalnika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>External IP address:</source>
        <translation>Zunanji IP naslov:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Copy &amp;All</source>
        <translation>Kopiraj &amp;vse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <location filename="../mainwindow.cpp" line="215"/>
        <location filename="../mainwindow.cpp" line="229"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute ni nameščen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Tarceroute ni nameščen. Namestim zdaj?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroute ni bil nameščen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Namestitev Traceroute ni možna. Vzrok je lahko v rabi živega CD ali v nedosegljivosti programskega skladišča,</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute ni nameščen in ga ni mogoče namestiti, ker ni bila najdena spletna povezava.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>No destination host</source>
        <translation>Ni ciljnega gostitelja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Please fill in the destination host field</source>
        <translation>Prosimo izpolnite polje za ciljnega gostitelja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Loaded Drivers</source>
        <translation>Naloženi gonilniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>Unloaded Drivers</source>
        <translation>Nenaloženi gonilniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Blocked Drivers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Blocked Broadcom Drivers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="894"/>
        <source>enabled</source>
        <translation>omogočeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>disabled</source>
        <translation>onemogočeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="900"/>
        <source>WiFi hardware switch is off</source>
        <translation>Stikalo za WFi strojno opremo je izklopljeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Locirajte Windows gonilnik, ki ga želite dodati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Datoteka s podatki za Windows namestitev (*.inf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>*.sys file not found</source>
        <translation>*.sys datoteka ni bila najdena</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>*.sys datoteka se mora nahajati na isti lokaciji kot *.inf datoteka. %1 ni bilo mogoče najti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="948"/>
        <source>sys file reference not found</source>
        <translation>reference za datoteko sys ni bilo mogoče najti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="948"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Glede na informacije v inf datoteki, ni bilo mogoče najti ustrezne sys datoteke za izbrani gonilnik.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="967"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Ndiswrapper gonilnik je bil odstranjen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1013"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1014"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>MX Linux program za konfiguriranje omrežja in odpravljanje napak</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1016"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Copyright (c) MEPIS LLC and MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1017"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>You must run this program as root.</source>
        <translation>Ta program morate zagnati kot root</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ndiswrapper ni nameščen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>driver installed</source>
        <translation>gonilnik je nameščen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source> and in use by </source>
        <translation>in ga uporablja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>. Alternate driver: </source>
        <translation>. Alternativni gonilnik: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Driver removed from blocklist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>Driver removed from blocklist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Module blocked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Installation successful</source>
        <translation>Namesitev je bila uspešna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="789"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Pojavila se je napaka. Ndiswrapper gonilnika ni bilo mogoče prevesti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="792"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Pojavila se je napaka. Ndiswrapper ni bilo mogoče namestiti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="804"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Napaka pri odtranjevanju programa Ndiswrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="855"/>
        <source>Unblock Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Block Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="995"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Naprav nisem mogel odkleniti.
WiFi naprava ali naprave so morda že odklenjene.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>WiFi devices unlocked.</source>
        <translation>WiFi naprave so odklenjene.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1040"/>
        <location filename="../mainwindow.cpp" line="1041"/>
        <source>Driver loaded successfully</source>
        <translation>Gonilnik je uspešno naložen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1056"/>
        <location filename="../mainwindow.cpp" line="1057"/>
        <source>Driver unloaded successfully</source>
        <translation>Gonilnik je bil uspešno odstranjen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Could not load </source>
        <translation>Neuspešno nalaganje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>Could not unload </source>
        <translation>neuspešno odstranjevanje</translation>
    </message>
</context>
</TS>
